| Title: | BCEA web app |
|---|---|
| Description: | Bayesian Cost Effectiveness Analysis (BCEA) web app using Shiny. |
| Authors: | Gianluca Baio [aut, cre, cph] (ORCID: <https://orcid.org/0000-0003-4314-2570>), Andrea Berardi [aut] (ORCID: <https://orcid.org/0000-0002-2906-496X>), Anna Heath [aut] (ORCID: <https://orcid.org/0000-0002-7263-4251>), Nathan Green [aut] (ORCID: <https://orcid.org/0000-0003-2745-1736>) |
| Maintainer: | Gianluca Baio <[email protected]> |
| License: | GPL (>= 3) |
| Version: | 0.0.0.9001 |
| Built: | 2026-05-25 07:52:22 UTC |
| Source: | https://github.com/giabaio/BCEAweb |
Launches the web-app
BCEAweb(e = NULL, c = NULL, parameters = NULL, launch.browser = TRUE, ...)BCEAweb(e = NULL, c = NULL, parameters = NULL, launch.browser = TRUE, ...)
e |
A matrix containing the simulations for the effectiveness variable (with number of simulation rows and number of interventions columns). Defaults at NULL, which means the user has to load their own values using the web-interface |
c |
A matrix containing the simulations for the cost variable (with number of simulation rows and number of interventions columns). Defaults at NULL, which means the user has to load their own values using the web-interface |
parameters |
A matrix with the simulations for all the relevant model parameters. Defaults at NULL, which means the user has to load their own values using the web-interface |
launch.browser |
Defaults to |
... |
Additional parameters. |
Gianluca Baio
Baio, G., Dawid, A. P. (2011). Probabilistic Sensitivity Analysis in Health Economics. Statistical Methods in Medical Research doi:10.1177/0962280211419832.
Baio G. (2012). Bayesian Methods in Health Economics. CRC/Chapman Hall, London
## Not run: data(Vaccine) BCEAweb(eff,cost,vaccine_mat) ## End(Not run)## Not run: data(Vaccine) BCEAweb(eff,cost,vaccine_mat) ## End(Not run)
Internal launch function
launch(e, c, parameters, launch.browser = TRUE, ...)launch(e, c, parameters, launch.browser = TRUE, ...)
e |
A matrix containing the simulations for the effectiveness variable (with number of simulation rows and number of interventions columns). Defaults at NULL, which means the user has to load their own values using the web-interface |
c |
A matrix containing the simulations for the cost variable (with number of simulation rows and number of interventions columns). Defaults at NULL, which means the user has to load their own values using the web-interface |
parameters |
A matrix with the simulations for all the relevant model parameters. Defaults at NULL, which means the user has to load their own values using the web-interface |
launch.browser |
Defaults to |
... |
Additional parameters. |
runApp
Constructs the automated report from the output of the BCEA.
make.report(he, evppi = NULL, ext = "pdf", echo = FALSE, ...)make.report(he, evppi = NULL, ext = "pdf", echo = FALSE, ...)
he |
A |
evppi |
An object obtained as output to a call to |
ext |
A string of text to indicate the extension of the
resulting output file. Possible options are |
echo |
A string (default to |
... |
Additional parameters. For example, the user can specify the
value of the willingness to pay |
Gianluca Baio
Baio, G., Dawid, A. P. (2011). Probabilistic Sensitivity Analysis in Health Economics. Statistical Methods in Medical Research doi:10.1177/0962280211419832.
Baio G. (2012). Bayesian Methods in Health Economics. CRC/Chapman Hall, London
Baio G., Heath, A., Berardi, A. and Green, N. (2025). Bayesian Cost-Effectiveness Analysis with the R package BCEA (2nd Edition). Springer
## Not run: data(Vaccine, package = "BCEA") m <- bcea(eff, cost, ref = 2) make.report(m) ## End(Not run)## Not run: data(Vaccine, package = "BCEA") m <- bcea(eff, cost, ref = 2) make.report(m) ## End(Not run)
This data set contains the results of a Bayesian analysis modeling the clinical outputs and costs for an economic evaluation of four different smoking cessation interventions.
A list containing the variables for the cost-effectiveness analysis:
A matrix of 500 simulations from the posterior distribution of the overall costs for the four strategies.
A dataset with characteristics of smokers in the UK population.
A matrix of 500 simulations from the posterior distribution of the clinical benefits for the four strategies.
A matrix of 500 simulations from the posterior distribution of the life years gained with each strategy.
A matrix of 500 simulations from the posterior distribution of the probability of smoking cessation with each strategy.
A data frame with inputs for the network meta-analysis,
containing: nobs (record ID), s (study ID), i
(intervention ID), r_i (number of patients who quit),
n_i (total patients in arm), and b_i (reference
intervention for the study).
A matrix of results from the network meta-analysis model
run on the smoking object.
A character vector of labels for the four strategies.
Effectiveness data adapted from Hasselblad V. (1998). "Meta-analysis of Multitreatment Studies". Medical Decision Making, 18:37-43.
Cost and population data adapted from various sources:
Taylor, D.H. Jr, et al. (2002). "Benefits of smoking cessation on longevity". American Journal of Public Health, 92(6).
Action on Smoking and Health (ASH) (2013). "ASH fact sheet on smoking statistics". https://ash.org/wp-content/uploads/2014/05/ASH-Annual-Report-2014.pdf.
Flack, S., et al. (2007). "Cost-effectiveness of interventions for smoking cessation". York Health Economics Consortium.
McGhan, W.F.D., and Smith, M. (1996). "Pharmacoeconomic analysis of smoking-cessation interventions". American Journal of Health-System Pharmacy, 53:45-52.
Baio G. (2012). Bayesian Methods in Health Economics. CRC/Chapman & Hall, London.
This CSV file contains simulated parameter data for the Smoking Cessation example.
A CSV file with 500 rows and 4 variables:
Simulations for the probability of quitting in intervention 1
Simulations for the probability of quitting in intervention 2
Simulations for the probability of quitting in intervention 3
Simulations for the probability of quitting in intervention 4
Generated for package examples
## Not run: csv_file <- system.file("extdata", "smoking_parameters.csv", package = "BCEAweb") data <- read.csv(csv_file) head(data) ## End(Not run)## Not run: csv_file <- system.file("extdata", "smoking_parameters.csv", package = "BCEAweb") data <- read.csv(csv_file) head(data) ## End(Not run)
This CSV file contains simulated outputs for the Smoking Cessation example.
A CSV file with 500 rows and 4 variables:
Simulations for the effects in intervention 1
Simulations for the costs in intervention 1
Simulations for the effects in intervention 2
Simulations for the costs in intervention 2
Simulations for the effects in intervention 3
Simulations for the effects in intervention 3
Simulations for the effects in intervention 4
Simulations for the costs in intervention 4
Generated for package examples
## Not run: csv_file <- system.file("extdata", "Smoking_results.csv", package = "BCEAweb") data <- read.csv(csv_file) head(data) ## End(Not run)## Not run: csv_file <- system.file("extdata", "Smoking_results.csv", package = "BCEAweb") data <- read.csv(csv_file) head(data) ## End(Not run)
This data set contains the results of a Bayesian analysis modeling the clinical outputs and costs associated with an influenza vaccination program.
A list containing variables for the influenza vaccination model:
A matrix of simulations of the overall costs for the two treatments.
Coordinates for plotting cost distributions.
A matrix of simulations of the costs for GP visits.
A matrix of simulations of the costs for hospitalisations.
A matrix of simulations of the costs for over-the-counter medications.
A matrix of simulations of the costs for time off work.
A matrix of simulations of the costs for time to get vaccinated.
A matrix of simulations of the costs for travel to get vaccinated.
A matrix of simulations of the overall costs for first-line treatment.
A matrix of simulations of the overall costs for second-line treatment.
A matrix of simulations of the costs for vaccination.
A matrix of simulations of the clinical benefits.
Coordinates for plotting effectiveness distributions.
The number of subjects in the reference population.
The number of clinical outcomes analysed.
The number of health-care resources under study.
A vector of QALYs associated with adverse events.
A vector of QALYs associated with death.
A vector of QALYs associated with hospitalisation.
A vector of QALYs associated with influenza infection.
A vector of QALYs associated with pneumonia.
A character vector of labels for the two treatments.
A matrix of simulations for the parameters in the original model.
Adapted from Turner D, et al. (2006). "The cost-effectiveness of influenza vaccination of healthy adults 50-64 years of age". Vaccine, 24:1035-1043.
Baio, G., & Dawid, A. P. (2011). "Probabilistic Sensitivity Analysis in Health Economics". Statistical Methods in Medical Research. doi:10.1177/0962280211419832.
This CSV file contains simulated outputs for the Vaccine example.
A CSV file with 500 rows and 2 variables:
Simulations for the effects in intervention 1
Simulations for the costs in intervention 1
Simulations for the effects in intervention 2
Simulations for the costs in intervention 2
Generated for package examples
## Not run: csv_file <- system.file("extdata", "Vaccine_results.csv", package = "BCEAweb") data <- read.csv(csv_file) head(data) ## End(Not run)## Not run: csv_file <- system.file("extdata", "Vaccine_results.csv", package = "BCEAweb") data <- read.csv(csv_file) head(data) ## End(Not run)